@@ -48,7 +48,7 @@
 #include <libpanel-util/panel-show.h>
 #include <libpanel-util/panel-xdg.h>
 
-#include "nothing.h"
+#include "free-the-fish.h"
 #include "panel-util.h"
 #include "panel-globals.h"
 #include "panel-enums.h"
@@ -527,14 +527,20 @@ panel_run_dialog_execute (PanelRunDialog *dialog)
 		g_free (command);
 		return;
 	}
-	
+
 	/* evil eggies, do not translate! */
 	if (!strcmp (command, "free the fish")) {
-		start_screen_check ();
+		free_the_fish ();
 
 		g_free (command);
 		gtk_widget_destroy (dialog->run_dialog);
 		return;
+	} else if (!strcmp (command, "catch the fish")) {
+		catch_the_fish ();
+
+		g_free(command);
+		gtk_widget_destroy(dialog->run_dialog);
+		return;
 	}
 		
 	error = NULL;
@@ -806,7 +812,7 @@ panel_run_dialog_find_command_idle (PanelRunDialog *dialog)
 		}
 
 		g_free (exec);
-		g_object_unref (icon);
+		g_clear_object (&icon);
 		g_free (name);
 		g_free (comment);
 	
@@ -913,8 +919,11 @@ get_all_applications (void)
 	GMenuTree          *tree;
 	GMenuTreeDirectory *root;
 	GSList             *retval;
+	gchar              *applications_menu;
 
-	tree = gmenu_tree_new ("gnome-applications.menu", GMENU_TREE_FLAGS_SORT_DISPLAY_NAME);
+	applications_menu = get_applications_menu ();
+	tree = gmenu_tree_new (applications_menu, GMENU_TREE_FLAGS_SORT_DISPLAY_NAME);
+	g_free (applications_menu);
 
 	if (!gmenu_tree_load_sync (tree, NULL))
 		return NULL;
@@ -1293,8 +1302,8 @@ file_button_clicked (GtkButton      *button,
 	chooser = gtk_file_chooser_dialog_new (_("Choose a file to append to the command..."),
 					       GTK_WINDOW (dialog->run_dialog),
 					       GTK_FILE_CHOOSER_ACTION_OPEN,
-					       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					       GTK_STOCK_OK, GTK_RESPONSE_OK,
+					       _("_Cancel"), GTK_RESPONSE_CANCEL,
+					       _("_OK"), GTK_RESPONSE_OK,
 					       NULL);
 	
 	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser),
